Learn R Programming

LJmp3converter (version 1.0.7)

run_converter_app: Launch the Video to MP3 Converter App

Description

This function converts video files to MP3. It provides a simple interface for selecting an input folder and processing the files, with the converted MP3 files saved in the same input folder.

Usage

run_converter_app()

Arguments

Value

No return value, called for side effects.

Examples

Run this code
if (FALSE) {
if (interactive()) {
  run_converter_app()
}
}

Run the code above in your browser using DataLab